*********
Utilities
*********

.. automodule:: networkx.utils
.. currentmodule:: networkx.utils

Helper functions
----------------

.. autosummary::
   :toctree: generated/

   is_string_like
   flatten
   iterable
   is_list_of_ints
   _get_fh

Data structures and Algorithms
------------------------------
.. autosummary::
   :toctree: generated/

   UnionFind.union

Random sequence generators
--------------------------
.. autosummary::
   :toctree: generated/

   pareto_sequence
   powerlaw_sequence
   uniform_sequence
   cumulative_distribution
   discrete_sequence


SciPy random sequence generators
----------------------------------
.. autosummary::
   :toctree: generated/

   scipy_pareto_sequence
   scipy_powerlaw_sequence
   scipy_poisson_sequence
   scipy_uniform_sequence
   scipy_discrete_sequence

